model.matrix.gnm: Local Design Matrix for a Generalized Nonlinear Model
Description
This method extracts or evaluates a local design matrix for a
generalized nonlinear model
Usage
## S3 method for class 'gnm':
model.matrix(object, coef = NULL, ...)
Arguments
object
an object of class gnm.
coef
if specified, the vector of coefficients at which the
local design matrix is evaluated.
...
further arguments.
Value
If coef = NULL, the local design matrix evaluated at
coef(object) (extracted from object if possible).
Otherwise, the local design matrix evaluated at coef.